@@ -8,7 +8,11 @@ class Server(object):
     address_family = socket.AF_INET
     socket_type = socket.SOCK_STREAM
 
-    def __init__(self, listener, application=None, backlog=None):
+    def __init__(self, listener, application=None, backlog=2048,
+                 socket_type=socket.SOCK_STREAM,
+                 address_family=socket.AF_INET):
+        self.address_family = address_family
+        self.socket_type = socket_type
         eventlet.monkey_patch()
         host, port = listener
         self.socket = create_socket(host, port, self.address_family,
